@@ -61,6 +61,14 @@ class Libvirt(object):
                                     'bash -x /root/network.sh'),
         )
 
+    def resize(self, name, definition):
+        sh.qemu_img.create('-f', 'qcow2', '-o', 'preallocation=metadata',
+                           self.host_image_name(name), definition['disk'])
+        sh.virt_resize(
+            '--expand', '/dev/sda1',
+            self.image_name(),
+            self.host_image_name(name))
+
     def get(self, name):
         try:
             return self.lv.lookupByName(name)
@@ -70,10 +78,17 @@ class Libvirt(object):
     def _create_or_update(self, definition):
         name = definition['name']
         if self.get(name) is not None:
-            return None
+            info = {
+                'ipv4': self.get_ipv4(name),
+                'port': definition['port'],
+            }
+            Hosts(self.config_dir).create_or_update(
+                definition['name'], info['ipv4'], info['port'])
+            return info
         log.info(f"{name}: building image")
         self.image_builder()
-        sh.cp('--sparse=always', self.image_name(), self.host_image_name(name))
+        log.info(f"{name}: copy and resize image")
+        self.resize(name, definition)
         log.info(f"{name}: preparing image")
         self.sysprep(name, definition)
         log.info(f"{name}: creating host")
@@ -130,6 +145,11 @@ class Libvirt(object):
 
     def get_definition(self, name, definition):
         r = {}
+        #
+        # This hardcoded MAC is convenient for testing purposes.
+        # It helps to have a fixed IP for the bind server. It
+        # is not a requirement.
+        #
         if name == 'bind-host':
             r['mac'] = f',mac={Libvirt.BIND_MAC}'
         else:
@@ -143,7 +163,7 @@ class Libvirt(object):
             'name': name,
             'port': definition.get('ansible_port', '22'),
             'ram': definition.get('libvirt_ram', '2048'),
-            # 'disk': definition.get('libvirt_disk', '20G'),
+            'disk': definition.get('libvirt_disk', '20G'),
             'network_interface_unconfigured': definition.get('network_interface_unconfigured'),
             'network_interface_routed': definition.get('network_interface_routed'),
             'network_interface_not_routed': definition.get('network_interface_not_routed'),
@@ -166,7 +186,7 @@ class Libvirt(object):
             '--no-cache',
             '--output', image,
             '--format', 'qcow2',
-            '--size', '20G',
+            '--size', '6G',
             '--install', 'sudo',
             '--root-password', 'disabled',
             '--run-command', 'dpkg-reconfigure --frontend=noninteractive openssh-server',
