@@ -3,7 +3,8 @@ testinfra_hosts = ['ansible://bind-host']
 
 def openstack(host, cmd):
     cmd = host.run(f"""
-    . /usr/lib/backup/openrc.sh
+    export OS_CLIENT_CONFIG_FILE=/usr/lib/backup/clouds.yml
+    export OS_CLOUD=production
     openstack {cmd}
     """)
     print(cmd.stderr)
