@@ -7,6 +7,6 @@ def test_set_options():
     parser = argparse.ArgumentParser()
     assert options.set_options(parser) == parser
     args = parser.parse_args([])
-    driver = 'DRIVER'
+    driver = 'libvirt'
     args = parser.parse_args(['--driver', driver])
     assert args.driver == driver
