@@ -15,13 +15,13 @@ from enough.common.openstack import Stack, Heat, OpenStack
 # Stack
 #
 @pytest.mark.openstack_integration
-def test_stack_create_or_update(openstack_name, openstack_provider,
+def test_stack_create_or_update(openstack_name, openstack_variables,
                                 dot_openstack):
     name = openstack_name
     network = openstack_name
     class_c = '10.101.30'
     cidr = f'{class_c}.0/24'
-    d = Heat.hostvars_to_stack(openstack_name, openstack_provider)
+    d = Heat.hostvars_to_stack(openstack_name, openstack_variables)
     d.update(
         internal_network=network,
         internal_network_cidr=cidr
@@ -177,8 +177,8 @@ def test_backup_create_no_names(openstack_name, dot_openstack, caplog):
 
 @pytest.mark.openstack_integration
 def test_openstack_replace_volume(openstack_name, dot_openstack,
-                                  openstack_provider):
-    d = Heat.hostvars_to_stack(openstack_name, openstack_provider)
+                                  openstack_variables):
+    d = Heat.hostvars_to_stack(openstack_name, openstack_variables)
     d.update({
         'volumes': [
             {
@@ -217,9 +217,9 @@ def test_openstack_replace_volume(openstack_name, dot_openstack,
 
 @pytest.mark.openstack_integration
 def test_openstack_volume_resize_ok(openstack_name, dot_openstack,
-                                    openstack_provider):
+                                    openstack_variables):
     size = 1
-    d = Heat.hostvars_to_stack(openstack_name, openstack_provider)
+    d = Heat.hostvars_to_stack(openstack_name, openstack_variables)
     d.update({
         'volumes': [
             {
@@ -253,8 +253,8 @@ def test_openstack_volume_resize_ok(openstack_name, dot_openstack,
 
 
 @pytest.mark.openstack_integration
-def test_openstack_volume_resize_no_volume(openstack_name, dot_openstack, openstack_provider):
-    d = Heat.hostvars_to_stack(openstack_name, openstack_provider)
+def test_openstack_volume_resize_no_volume(openstack_name, dot_openstack, openstack_variables):
+    d = Heat.hostvars_to_stack(openstack_name, openstack_variables)
     s = Stack(settings.CONFIG_DIR, d)
     s.set_public_key(f'{settings.CONFIG_DIR}/infrastructure_key.pub')
     s.create_or_update()
