@@ -9,6 +9,8 @@ def test_enough_install_script(capsys, mocker):
     assert main(['--debug', 'install', 'internal/data/install.sh']) == 0
     out, err = capsys.readouterr()
     assert 'docker run' in out
+    assert 'libvirt' in out
+    assert 'docker.sock' in out
     assert 'function()' not in out
     assert __version__ in out
 
